==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeFileFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class DownwardAPIVolumeFileFluentImpl<A extends io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent<A>{
  public DownwardAPIVolumeFileFluentImpl() {
  }
  public DownwardAPIVolumeFileFluentImpl(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile instance) {
    this.withFieldRef(instance.getFieldRef()); 
    this.withMode(instance.getMode()); 
    this.withPath(instance.getPath()); 
    this.withResourceFieldRef(instance.getResourceFieldRef()); 
  }
  private io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder fieldRef;
  private java.lang.Integer mode;
  private java.lang.String path;
  private io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder resourceFieldRef;
  
  /**
   * This method has been deprecated, please use method buildFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector getFieldRef() {
    return this.fieldRef!=null?this.fieldRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector buildFieldRef() {
    return this.fieldRef!=null?this.fieldRef.build():null;
  }
  public A withFieldRef(io.fabric8.kubernetes.api.model.ObjectFieldSelector fieldRef) {
    _visitables.get("fieldRef").remove(this.fieldRef);
    if (fieldRef!=null){ this.fieldRef= new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder(fieldRef); _visitables.get("fieldRef").add(this.fieldRef);} return (A) this;
  }
  public java.lang.Boolean hasFieldRef() {
    return this.fieldRef != null;
  }
  public A withNewFieldRef(java.lang.String apiVersion,java.lang.String fieldPath) {
    return (A)withFieldRef(new ObjectFieldSelector(apiVersion, fieldPath));
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRef() {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.FieldRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item) {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.FieldRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editFieldRef() {
    return withNewFieldRefLike(getFieldRef());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRef() {
    return withNewFieldRefLike(getFieldRef() != null ? getFieldRef(): new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item) {
    return withNewFieldRefLike(getFieldRef() != null ? getFieldRef(): item);
  }
  public java.lang.Integer getMode() {
    return this.mode;
  }
  public A withMode(java.lang.Integer mode) {
    this.mode=mode; return (A) this;
  }
  public java.lang.Boolean hasMode() {
    return this.mode != null;
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildResourceFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector getResourceFieldRef() {
    return this.resourceFieldRef!=null?this.resourceFieldRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector buildResourceFieldRef() {
    return this.resourceFieldRef!=null?this.resourceFieldRef.build():null;
  }
  public A withResourceFieldRef(io.fabric8.kubernetes.api.model.ResourceFieldSelector resourceFieldRef) {
    _visitables.get("resourceFieldRef").remove(this.resourceFieldRef);
    if (resourceFieldRef!=null){ this.resourceFieldRef= new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder(resourceFieldRef); _visitables.get("resourceFieldRef").add(this.resourceFieldRef);} return (A) this;
  }
  public java.lang.Boolean hasResourceFieldRef() {
    return this.resourceFieldRef != null;
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRef() {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.ResourceFieldRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item) {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.ResourceFieldRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editResourceFieldRef() {
    return withNewResourceFieldRefLike(getResourceFieldRef());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRef() {
    return withNewResourceFieldRefLike(getResourceFieldRef() != null ? getResourceFieldRef(): new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item) {
    return withNewResourceFieldRefLike(getResourceFieldRef() != null ? getResourceFieldRef(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DownwardAPIVolumeFileFluentImpl that = (DownwardAPIVolumeFileFluentImpl) o;
    if (fieldRef != null ? !fieldRef.equals(that.fieldRef) :that.fieldRef != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (resourceFieldRef != null ? !resourceFieldRef.equals(that.resourceFieldRef) :that.resourceFieldRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldRef,  mode,  path,  resourceFieldRef,  super.hashCode());
  }
  public class FieldRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluentImpl<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<N>> implements io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FieldRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectFieldSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder(this, item);
    }
    FieldRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder builder;
    public N and() {
      return (N) DownwardAPIVolumeFileFluentImpl.this.withFieldRef(builder.build());
    }
    public N endFieldRef() {
      return and();
    }
    
  }
  public class ResourceFieldRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluentImpl<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>> implements io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ResourceFieldRefNestedImpl(io.fabric8.kubernetes.api.model.ResourceFieldSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder(this, item);
    }
    ResourceFieldRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder builder;
    public N and() {
      return (N) DownwardAPIVolumeFileFluentImpl.this.withResourceFieldRef(builder.build());
    }
    public N endResourceFieldRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/DownwardAPIVolumeFileFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DownwardAPIVolumeFileFluentImpl<A extends io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent<A>{
  public DownwardAPIVolumeFileFluentImpl() {
  }
  public DownwardAPIVolumeFileFluentImpl(io.fabric8.kubernetes.api.model.DownwardAPIVolumeFile instance) {
    this.withFieldRef(instance.getFieldRef()); 
    this.withMode(instance.getMode()); 
    this.withPath(instance.getPath()); 
    this.withResourceFieldRef(instance.getResourceFieldRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder fieldRef;
  private java.lang.Integer mode;
  private java.lang.String path;
  private io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder resourceFieldRef;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector getFieldRef() {
    return this.fieldRef!=null?this.fieldRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectFieldSelector buildFieldRef() {
    return this.fieldRef!=null?this.fieldRef.build():null;
  }
  public A withFieldRef(io.fabric8.kubernetes.api.model.ObjectFieldSelector fieldRef) {
    _visitables.get("fieldRef").remove(this.fieldRef);
    if (fieldRef!=null){ this.fieldRef= new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder(fieldRef); _visitables.get("fieldRef").add(this.fieldRef);} return (A) this;
  }
  public java.lang.Boolean hasFieldRef() {
    return this.fieldRef != null;
  }
  public A withNewFieldRef(java.lang.String apiVersion,java.lang.String fieldPath) {
    return (A)withFieldRef(new ObjectFieldSelector(apiVersion, fieldPath));
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRef() {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.FieldRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item) {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.FieldRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editFieldRef() {
    return withNewFieldRefLike(getFieldRef());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRef() {
    return withNewFieldRefLike(getFieldRef() != null ? getFieldRef(): new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRefLike(io.fabric8.kubernetes.api.model.ObjectFieldSelector item) {
    return withNewFieldRefLike(getFieldRef() != null ? getFieldRef(): item);
  }
  public java.lang.Integer getMode() {
    return this.mode;
  }
  public A withMode(java.lang.Integer mode) {
    this.mode=mode; return (A) this;
  }
  public java.lang.Boolean hasMode() {
    return this.mode != null;
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildResourceFieldRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector getResourceFieldRef() {
    return this.resourceFieldRef!=null?this.resourceFieldRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ResourceFieldSelector buildResourceFieldRef() {
    return this.resourceFieldRef!=null?this.resourceFieldRef.build():null;
  }
  public A withResourceFieldRef(io.fabric8.kubernetes.api.model.ResourceFieldSelector resourceFieldRef) {
    _visitables.get("resourceFieldRef").remove(this.resourceFieldRef);
    if (resourceFieldRef!=null){ this.resourceFieldRef= new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder(resourceFieldRef); _visitables.get("resourceFieldRef").add(this.resourceFieldRef);} return (A) this;
  }
  public java.lang.Boolean hasResourceFieldRef() {
    return this.resourceFieldRef != null;
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRef() {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.ResourceFieldRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item) {
    return new io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluentImpl.ResourceFieldRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editResourceFieldRef() {
    return withNewResourceFieldRefLike(getResourceFieldRef());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRef() {
    return withNewResourceFieldRefLike(getResourceFieldRef() != null ? getResourceFieldRef(): new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRefLike(io.fabric8.kubernetes.api.model.ResourceFieldSelector item) {
    return withNewResourceFieldRefLike(getResourceFieldRef() != null ? getResourceFieldRef(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DownwardAPIVolumeFileFluentImpl that = (DownwardAPIVolumeFileFluentImpl) o;
    if (fieldRef != null ? !fieldRef.equals(that.fieldRef) :that.fieldRef != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (resourceFieldRef != null ? !resourceFieldRef.equals(that.resourceFieldRef) :that.resourceFieldRef != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldRef,  mode,  path,  resourceFieldRef,  additionalProperties,  super.hashCode());
  }
  public class FieldRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectFieldSelectorFluentImpl<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<N>> implements io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.FieldRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FieldRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectFieldSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder(this, item);
    }
    FieldRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectFieldSelectorBuilder builder;
    public N and() {
      return (N) DownwardAPIVolumeFileFluentImpl.this.withFieldRef(builder.build());
    }
    public N endFieldRef() {
      return and();
    }
    
  }
  public class ResourceFieldRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ResourceFieldSelectorFluentImpl<io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>> implements io.fabric8.kubernetes.api.model.DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ResourceFieldRefNestedImpl(io.fabric8.kubernetes.api.model.ResourceFieldSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder(this, item);
    }
    ResourceFieldRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ResourceFieldSelectorBuilder builder;
    public N and() {
      return (N) DownwardAPIVolumeFileFluentImpl.this.withResourceFieldRef(builder.build());
    }
    public N endResourceFieldRef() {
      return and();
    }
    
  }
  
}
